@@ -261,6 +261,7 @@ class EnsembleSampler(object):
         thin=None,
         store=True,
         progress=False,
+        progress_kwargs=None,
     ):
         """Advance the chain as a generator
 
@@ -287,6 +288,8 @@ class EnsembleSampler(object):
                 ``'notebook'``, which shows a progress bar suitable for
                 Jupyter notebooks.  If ``False``, no progress bar will be
                 shown.
+            progress_kwargs (Optional[dict]): A ``dict`` of keyword arguments
+                to be passed to the tqdm call.
             skip_initial_state_check (Optional[bool]): If ``True``, a check
                 that the initial_state can fully explore the space will be
                 skipped. (default: ``False``)
@@ -383,10 +386,12 @@ class EnsembleSampler(object):
         model = Model(
             self.log_prob_fn, self.compute_log_prob, map_fn, self._random
         )
+        if progress_kwargs is None:
+            progress_kwargs = {}
 
         # Inject the progress bar
         total = None if iterations is None else iterations * yield_step
-        with get_progress_bar(progress, total) as pbar:
+        with get_progress_bar(progress, total, **progress_kwargs) as pbar:
             i = 0
             for _ in count() if iterations is None else range(iterations):
                 for _ in range(yield_step):
